TerraFlutterRt class

Constructors

TerraFlutterRt()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

platformVersion Future<String?>
no setter

Static Methods

connectDevice(Device device) Future<bool?>
connectWatchOS() Future<bool>
================================ Watch OS (Apple Watch) Only Methods
disconnect(Connection connection) Future<bool?>
getUserId() Future<String?>
init(String devId, String? referenceId) Future<bool?>
================================ SDK Initialisation Methods
initConnection(String token) Future<bool?>
myUtilsHandler(MethodCall methodCall) Future
================================ End of exposed methods
pauseWatchOSWorkout() Future<bool>
resumeWatchOSWorkout() Future<bool>
startDeviceScan(Connection connection, {bool useCache = false, ConnectionCallback? connectionCallback}) Future<bool?>
startDeviceScanToCallback(Connection connection, DeviceCallback deviceCallback, {ConnectionCallback? connectionCallback}) Future<bool?>
startRealtimeToApp(Connection connection, List<DataType> types, UpdateCallback callback) Future<bool?>
startRealtimeToServer(Connection connection, List<DataType> types, String token) Future<bool?>
================================ Streaming and Connection Methods
stopRealtime(Connection connection) Future<bool?>
stopWatchOSWorkout() Future<bool>